@@ -1,4 +1,4 @@
-# $Id: /mirror/coderepos/lang/perl/Data-Valve/trunk/lib/Data/Valve/BucketStore/Memory.pm 66548 2008-07-22T00:38:42.978696Z daisuke  $
+# $Id: /mirror/coderepos/lang/perl/Data-Valve/trunk/lib/Data/Valve/BucketStore/Memory.pm 66567 2008-07-22T08:55:23.819173Z daisuke  $
 
 package Data::Valve::BucketStore::Memory;
 use Moose;
@@ -16,6 +16,25 @@ __PACKAGE__->meta->make_immutable;
 
 no Moose;
 
+sub fill {
+    my ($self, %args) = @_;
+
+    my $bucket = $self->store()->{ $args{key} };
+    if (! $bucket) {
+        $bucket = $self->create_bucket;
+        $self->store()->{ $args{key} } = $bucket;
+    }
+
+    1 while ( $bucket->try_push() );
+}
+
+sub reset {
+    my ($self, %args) = @_;
+
+    my $bucket = $self->store->{ $args{key} };
+    $bucket->reset();
+}
+
 sub create_bucket
 {
     my $self = shift;
@@ -48,6 +67,10 @@ Data::Valve::BucketStore::Memory - An In-Memory Bucket Store
 
 =head1 METHODS
 
+=head2 fill
+
+=head2 reset
+
 =head2 create_bucket
 
 =head2 try_push
